@@ -74,13 +74,13 @@ import locale
 import os
 from typing import Any, Dict, List, Optional, Tuple, Union
 
-from ae.base import app_name_guess                      # type: ignore
-from ae.paths import Collector                          # type: ignore
-from ae.files import FilesRegister                      # type: ignore
-from ae.inspector import stack_variables, try_eval      # type: ignore
+from ae.base import app_name_guess, file_content, sys_platform                                  # type: ignore
+from ae.paths import Collector                                                                  # type: ignore
+from ae.files import FilesRegister                                                              # type: ignore
+from ae.inspector import stack_variables, try_eval                                              # type: ignore
 
 
-__version__ = '0.1.12'
+__version__ = '0.1.14'
 
 
 MsgType = Union[str, Dict[str, str]]                    #: type of message translations within :data:`MSG_FILE_SUFFIX`
@@ -91,7 +91,17 @@ MSG_FILE_SUFFIX = 'Msg.txt'                             #: file name containing
 DEF_LANGUAGE = 'en'                                     #: language code of the messages in your app code
 DEF_ENCODING = 'UTF-8'                                  #: encoding of the messages in your app code
 
-_LANG, _ENC = locale.getdefaultlocale()
+
+if sys_platform() == 'android':                                                                     # pragma: no cover
+    from jnius import autoclass                                                                     # type: ignore
+
+    mActivity = autoclass('org.kivy.android.PythonActivity').mActivity
+    # copied from https://github.com/HelloZeroNet/ZeroNet-kivy/blob/master/src/platform_android.py
+    # deprecated since API level 24: _LANG = mActivity.getResources().getConfiguration().locale.toString()
+    _LANG = mActivity.getResources().getConfiguration().getLocales().get(0).toString()
+    _ENC = ''
+else:
+    _LANG, _ENC = locale.getdefaultlocale()  # type: ignore # mypy is not seeing the not _LANG checks (next code line)
 if not _LANG:
     _LANG = DEF_LANGUAGE     # pragma: no cover
 elif '_' in _LANG:
@@ -173,10 +183,9 @@ def load_language_file(file_name: str, encoding: str, language: str):
     :param encoding:        encoding id string.
     :param language:        language id string.
     """
-    with open(file_name, encoding=encoding) as file_handle:  # refactor with de.core.file_content into ae.core
-        file_content = file_handle.read()
-    if file_content:
-        lang_messages = ast.literal_eval(file_content)
+    content = file_content(file_name, encoding=encoding)
+    if content:
+        lang_messages = ast.literal_eval(content)
         if lang_messages:
             LOADED_LANGUAGES[language].update(lang_messages)
 
